TEONITE Deployment
==================

[![Build Status](https://drone.io/github.com/teonite/deployment/status.png)](https://drone.io/github.com/teonite/deployment/latest)

We have tried various deployment tools and since Python is your main choice
regarding language/technology we used Fabric most. But as always regarding
motivation to create a new tool, not all tools meet our expectations.

So we've created our own deployment tool based on Fabric (it uses Fabric to do
all operations on the remote server).

Full documentation can be found here:

https://tnt.sh/public/deployment/I7HOGGFV2INL/index.html
